Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1096)

Unified Diff: git_cl.py

Issue 11262057: git_cl sanity checks (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/depot_tools
Patch Set: Use explicit calls to merge-base in diff commands Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | scm.py » ('j') | scm.py » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: git_cl.py
diff --git a/git_cl.py b/git_cl.py
index 21ade2a28e9987cfdc76425e64f8f0f027b6b1e6..97285091d6778c42fede01d4de7f767ae544c2d1 100755
--- a/git_cl.py
+++ b/git_cl.py
@@ -163,6 +163,32 @@ def is_dirty_git_tree(cmd):
return True
return False
+
+def git_cl_sanity_checks(upstream_git_obj):
M-A Ruel 2012/10/28 20:53:02 Would still like a oneliner docstring for the purp
Isaac (away) 2012/10/28 21:16:42 Done.
+ # First verify that the commit we're diffing against is in our tree.
+ upstream_sha = RunGit(['rev-parse', '--verify', upstream_git_obj]).strip()
+ common_ancestor = RunGit(['merge-base', upstream_sha, 'HEAD']).strip()
+ if upstream_sha != common_ancestor:
+ print >> sys.stderr, (
+ 'ERROR: %s is not in the current branch. You may need to rebase your '
+ 'tracking branch' % upstream_sha)
+ return False
+
+ commits_in_diff = RunGit(
+ ['rev-list', '^%s' % upstream_sha, 'HEAD']).splitlines()
+ commits_in_origin = RunGit(
+ ['rev-list', '^%s' % upstream_sha, 'remotes/origin/master']).splitlines()
+
+ common_commits = set(commits_in_diff) & set(commits_in_origin)
+ if common_commits:
+ print >> sys.stderr, (
+ 'ERROR: Your diff contains %d commits already in origin/master.\n'
+ 'Run "git log --oneline origin/master..HEAD" to get a list of commits '
+ 'in the diff' % len(common_commits))
+ return False
+ return True
+
+
def MatchSvnGlob(url, base_url, glob_spec, allow_wildcards):
"""Return the corresponding git ref if |base_url| together with |glob_spec|
matches the full |url|.
@@ -607,6 +633,9 @@ or verify this branch is set up to track another (via the --track argument to
self.has_issue = False
def GetChange(self, upstream_branch, author):
+ if not git_cl_sanity_checks(upstream_branch):
+ DieWithError('\nGit sanity check failure')
+
root = RunCommand(['git', 'rev-parse', '--show-cdup']).strip() or '.'
absroot = os.path.abspath(root)
@@ -1018,8 +1047,8 @@ def CMDpresubmit(parser, args):
if args:
base_branch = args[0]
else:
- # Default to diffing against the "upstream" branch.
- base_branch = cl.GetUpstreamBranch()
+ # Default to diffing against the common ancestor of the upstream branch.
+ base_branch = RunGit(['merge-base', cl.GetUpstreamBranch(), 'HEAD']).strip()
cl.RunHook(committing=not options.upload, upstream_branch=base_branch,
may_prompt=False, verbose=options.verbose,
@@ -1216,9 +1245,9 @@ def CMDupload(parser, args):
# TODO(ukai): is it ok for gerrit case?
base_branch = args[0]
else:
- # Default to diffing against the "upstream" branch.
- base_branch = cl.GetUpstreamBranch()
- args = [base_branch + "..."]
+ # Default to diffing against common ancestor of upstream branch
+ base_branch = RunGit(['merge-base', cl.GetUpstreamBranch(), 'HEAD']).strip()
+ args = [base_branch]
if not options.bypass_hooks:
hook_results = cl.RunHook(committing=False, upstream_branch=base_branch,
@@ -1656,7 +1685,9 @@ def CMDtry(parser, args):
# Process --bot and --testfilter.
if not options.bot:
# Get try slaves from PRESUBMIT.py files if not specified.
- change = cl.GetChange(cl.GetUpstreamBranch(), None)
+ change = cl.GetChange(
+ RunGit(['merge-base', cl.GetUpstreamBranch(), 'HEAD']).strip(),
+ None)
options.bot = presubmit_support.DoGetTrySlaves(
change,
change.LocalPaths(),
« no previous file with comments | « no previous file | scm.py » ('j') | scm.py » ('J')

Powered by Google App Engine
This is Rietveld 408576698